package com.igzcode.java.web.net.mail;

import java.util.Properties;
import java.util.logging.Logger;

import javax.mail.Message;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeMessage;

import com.igzcode.java.web.util.ConfigUtil;

public class MailAsync extends Thread {
	
	static private final Logger _LOG = Logger.getLogger("com.igzcode.java.web.net.mail.MailAsync");

	private String _Server;
	
	private String _From;
	private String[] _To;
	private String[] _Cc;
	private String[] _Bcc;
	private String _Subject;
	private String _HtmlBody;
	
	
	public MailAsync(String p_server, String p_from, String[] p_to, String p_subject, String p_htmlBody) {
		_Server = p_server;
		_From 	 = p_from;
		_To	 	 = p_to;
		_Subject  = p_subject;
		_HtmlBody = p_htmlBody;
		_Cc		 = new String[] {};
		_Bcc		 = new String[] {};
	}

	public void run() {
		try {

			final Integer PORT_GOOGLEAPPS = 587; // smtp.google.com
			boolean isGoogleApps = PORT_GOOGLEAPPS.equals( new Integer (ConfigUtil.Env(_Server, "port")) );
			
			String host = ConfigUtil.Env(_Server, "host");
			String port = ConfigUtil.Env(_Server, "port");
			String usr = ConfigUtil.Env(_Server, "usr");
			String pwd = ConfigUtil.Env(_Server, "pwd");
			
			Properties props = new Properties();
			if ( isGoogleApps ){
				props.setProperty("mail.smtp.starttls.enable", "true");
				props.setProperty("mail.smtp.auth", "true");
				props.setProperty("mail.smtp.host", host);
				props.setProperty("mail.smtp.port", port);
				props.setProperty("mail.smtp.user", usr);
			}
			else {
				props.setProperty("mail.transport.protocol", "smtp");
				props.setProperty("mail.smtp.auth", "true");
				props.setProperty("mail.host", host);
				props.setProperty("mail.port", port);
				props.setProperty("mail.user", usr);
				props.setProperty("mail.password", ConfigUtil.Env(_Server, pwd));			
			}
			
			PasswordAuthenticator authenticator = new PasswordAuthenticator(usr, pwd);
		
			Session mailSession = Session.getInstance( props, authenticator );
			MimeMessage message = new MimeMessage(mailSession);
		
			Transport transport = mailSession.getTransport("smtp");

			message.setSubject( _Subject, "UTF-8" );
			
			message.setFrom( new InternetAddress(_From) );
			
			for ( String to : _To ) {
				message.addRecipient( Message.RecipientType.TO, new InternetAddress(to) );
			}
			
			for ( String cc : _Cc ) {
				message.addRecipient( Message.RecipientType.CC, new InternetAddress(cc) );
			}
			
			for ( String bcc : _Bcc ) {
				message.addRecipient( Message.RecipientType.CC, new InternetAddress(bcc) );
			}
			message.setContent(_HtmlBody, "text/html; charset=UTF-8");

			if ( isGoogleApps ){
				transport.connect(usr, pwd);
			}
			else {
				transport.connect();
			}
			
			transport.sendMessage(message, message.getRecipients(Message.RecipientType.TO));
			transport.close();
		}
		 catch (Exception e) {
			 _LOG.severe("Error sending email: To[" + _To + "] Subject[" + _Subject + "] HtmlBody[" + _HtmlBody + "]");
			 e.printStackTrace();
		}
		
	}

}
